@@ -1,80 +1,76 @@
-#!/usr/bin/env python2.7
-# -*- coding: utf-8 -*-
-
-import io
 import re
 from itertools import *
 
 if __name__ == "__main__":
-	import bikeshed.config
-	from bikeshed.messages import *
+    from bikeshed import config
+    from bikeshed.messages import *
 else:
-	from . import config
-	from .messages import *
-
-'''
-Explanation of the BSFONT font file format:
-
-BSFONT is a plain-text font format designed to be hand-authorable and easily readable.
-
-A BSFONT file starts with one or more metadata lines.
-These are lines of the form "Key: Value".
-* **Character Height**: Required.  It specifies how many lines tall each character in the font is.  (All letters must be the same height.)
-* **Space Width**: Optional.  This specifies the width of an ASCII space character in the font.  (Writing a space in the normal character format is hard to read.) If your font wants a space that isn't just whitespace, you can still specify it as a normal character.
-
-The first line that doesn't match the metadata format is assumed to be the start of the character data.
-The character data is composed of groups of lines each specifying how to render one character.
-The first line of each group is the character being described.  It should be the only text on the line.
-The next several lines (equal to the **Character Height**) are the character itself, rendered as ASCII art.
-Each letter is assumed to be monospace rectangular;
-if not all lines are the same width,
-they're end-padded with spaces to become rectangular.
-
-For ASCII letters, if you define only one casing,
-that rendering is used for both casings.
-That is, if you only want capital letters,
-just define it for "A", "B", etc,
-and it'll automatically apply to "a", "b", etc as well.
-
-Here is an example BSFONT file:
-
-```
-Character Height: 7
-Space Width: 5
-A
-   ███
-  ██ ██
- ██   ██
-██     ██
-█████████
-██     ██
-██     ██
-B
-████████
-██     ██
-██     ██
-████████
-██     ██
-██     ██
-████████
-```
-
-This defines a font capable of rendering text composed of "A", "B", "a", "b", and " ".
-
-'''
+    from . import config
+    from .messages import *
 
 
-class Font(object):
+class Font:
+    """
+    Explanation of the BSFONT font file format:
+
+    BSFONT is a plain-text font format designed to be hand-authorable and easily readable.
+
+    A BSFONT file starts with one or more metadata lines.
+    These are lines of the form "Key: Value".
+    * **Character Height**: Required.  It specifies how many lines tall each character in the font is.  (All letters must be the same height.)
+    * **Space Width**: Optional.  This specifies the width of an ASCII space character in the font.  (Writing a space in the normal character format is hard to read.) If your font wants a space that isn't just whitespace, you can still specify it as a normal character.
+
+    The first line that doesn't match the metadata format is assumed to be the start of the character data.
+    The character data is composed of groups of lines each specifying how to render one character.
+    The first line of each group is the character being described.  It should be the only text on the line.
+    The next several lines (equal to the **Character Height**) are the character itself, rendered as ASCII art.
+    Each letter is assumed to be monospace rectangular;
+    if not all lines are the same width,
+    they're end-padded with spaces to become rectangular.
+
+    For ASCII letters, if you define only one casing,
+    that rendering is used for both casings.
+    That is, if you only want capital letters,
+    just define it for "A", "B", etc,
+    and it'll automatically apply to "a", "b", etc as well.
+
+    Here is an example BSFONT file:
+
+    ```
+    Character Height: 7
+    Space Width: 5
+    A
+       ███
+      ██ ██
+     ██   ██
+    ██     ██
+    █████████
+    ██     ██
+    ██     ██
+    B
+    ████████
+    ██     ██
+    ██     ██
+    ████████
+    ██     ██
+    ██     ██
+    ████████
+    ```
+
+    This defines a font capable of rendering text composed of "A", "B", "a", "b", and " ".
+
+    """
+
     def __init__(self, fontfilename=config.scriptPath("bigblocks.bsfont")):
         try:
-            lines = io.open(fontfilename, 'r', encoding="utf-8").readlines()
+            lines = open(fontfilename, encoding="utf-8").readlines()
         except Exception as e:
             die("Couldn't find font file “{0}”:\n{1}", fontfilename, e)
         self.metadata, lines = parseMetadata(lines)
         self.characters = parseCharacters(self.metadata, lines)
 
     def write(self, text):
-        output = [''] * self.metadata["height"]
+        output = [""] * self.metadata["height"]
         for letterIndex, letter in enumerate(text):
             if letter in self.characters:
                 for i, line in enumerate(self.characters[letter]):
@@ -92,14 +88,9 @@ def parseMetadata(lines):
     # First line that's not of that form ends the metadata.
     # Returns the parsed metadata, and the non-metadata lines
     md = {}
-    nameMapping = {
-        "Character Height": "height",
-        "Space Width": "space-width"
-    }
-    valProcessors = {
-        "height": int,
-        "space-width": int
-    }
+    nameMapping = {"Character Height": "height", "Space Width": "space-width"}
+    valProcessors = {"height": int, "space-width": int}
+    i = 0
     for i, line in enumerate(lines):
         match = re.match(r"([^:]+):\s+(\S.*)", line)
         if not match:
@@ -118,14 +109,15 @@ def parseMetadata(lines):
 
 def parseCharacters(md, lines):
     import string
-    height = md['height']
+
+    height = md["height"]
     characters = {}
     if "space-width" in md:
-        characters[" "] = [" " * md['space-width']] * height
+        characters[" "] = [" " * md["space-width"]] * height
     for bigcharlines in grouper(lines, height + 1):
         littlechar = bigcharlines[0][0]
         bigchar = [line.strip("\n") for line in bigcharlines[1:]]
-        width = max(len(l) for l in bigchar)
+        width = max(len(line) for line in bigchar)
         for i, line in enumerate(bigchar):
             # Make sure the letter is a rectangle.
             if len(line) < width:
@@ -147,14 +139,12 @@ def replaceComments(font, inputFilename=None, outputFilename=None):
         match = re.match(r"\s*<!--\s*Big Text:\s*(\S.*)-->", line)
         if match:
             newtext = ["<!--\n"] + font.write(match.group(1).strip()) + ["-->\n"]
-            replacements.append({
-                'line': i,
-                'content': newtext
-            })
+            replacements.append({"line": i, "content": newtext})
     for r in reversed(replacements):
-        lines[r['line']:r['line'] + 1] = r['content']
+        lines[r["line"] : r["line"] + 1] = r["content"]
     writeOutputLines(outputFilename, inputFilename, lines)
 
+
 # Some utility functions
 
 
@@ -171,6 +161,7 @@ def getInputLines(inputFilename):
         # Otherwise, look for a *.src.html file.
         # Otherwise, use standard input.
         import glob
+
         if glob.glob("*.bs"):
             inputFilename = glob.glob("*.bs")[0]
         elif glob.glob("*.src.html"):
@@ -181,11 +172,14 @@ def getInputLines(inputFilename):
         if inputFilename == "-":
             lines = list(sys.stdin.readlines())
         else:
-            lines = io.open(inputFilename, 'r', encoding="utf-8").readlines()
-    except OSError:
-        die("Couldn't find the input file at the specified location '{0}'.", inputFilename)
+            lines = open(inputFilename, encoding="utf-8").readlines()
+    except FileNotFoundError:
+        die(
+            "Couldn't find the input file at the specified location '{0}'.",
+            inputFilename,
+        )
         return []
-    except IOError:
+    except OSError:
         die("Couldn't open the input file '{0}'.", inputFilename)
         return []
     return lines, inputFilename
@@ -196,21 +190,30 @@ def writeOutputLines(outputFilename, inputFilename, lines):
         outputFilename = inputFilename
     try:
         if outputFilename == "-":
-            sys.stdout.write(''.join(lines))
+            sys.stdout.write("".join(lines))
         else:
-            with io.open(outputFilename, "w", encoding="utf-8") as f:
-                f.write(''.join(lines))
+            with open(outputFilename, "w", encoding="utf-8") as f:
+                f.write("".join(lines))
     except Exception as e:
-        die("Something prevented me from saving the output document to {0}:\n{1}", outputFilename, e)
+        die(
+            "Something prevented me from saving the output document to {0}:\n{1}",
+            outputFilename,
+            e,
+        )
+
 
 if __name__ == "__main__":
     import argparse
+
     argparser = argparse.ArgumentParser(description="Outputs text as giant ASCII art.")
-    argparser.add_argument("--font", dest="fontPath", default=config.scriptPath("bigblocks.bsfont"),
-                           help="What .bsfont file to use to render the text with.")
-    argparser.add_argument("text",
-                           help="Text to ASCII-ify.")
+    argparser.add_argument(
+        "--font",
+        dest="fontPath",
+        default=config.scriptPath("bigblocks.bsfont"),
+        help="What .bsfont file to use to render the text with.",
+    )
+    argparser.add_argument("text", help="Text to ASCII-ify.")
     options = argparser.parse_args()
     font = Font(options.fontPath)
     for line in font.write(options.text):
-        print(line, end='')
+        print(line, end="")
