@@ -734,7 +734,7 @@ def replaceAwkwardCSSShorthands(text):
         escape, text = match.groups()
         if escape:
             return escapeHTML(match.group(0)[1:])
-        return f"<fake-production-placeholder class=production bs-autolink-syntax='{syntaxAttr}'>{text}</fake-production-placeholder>"
+        return f"<fake-production-placeholder class=production bs-autolink-syntax='{syntaxAttr}' data-opaque>{text}</fake-production-placeholder>"
 
     text = re.sub(r"(\\)?<<([^>\n]+)>>", replaceProduction, text)
 
