@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from . import config
 from .config import simplifyText
 from .h import *
@@ -9,26 +7,26 @@ from .messages import *
 def processHeadings(doc, scope="doc"):
     # scope arg can be "doc" or "all"
     # "doc" ignores things that are part of boilerplate
-    for el in findAll('h2, h3, h4, h5, h6', doc):
-        addClass(el, 'heading')
+    for el in findAll("h2, h3, h4, h5, h6", doc):
+        addClass(el, "heading")
     headings = []
     for el in findAll(".heading:not(.settled)", doc):
         if scope == "doc" and treeAttr(el, "boilerplate"):
             continue
         headings.append(el)
-    resetHeadings(doc, headings)
-    determineHeadingLevels(doc, headings)
+    resetHeadings(headings)
+    determineHeadingLevels(headings)
     addHeadingIds(doc, headings)
-    addHeadingAlgorithms(doc, headings)
+    addHeadingAlgorithms(headings)
     fixupIDs(doc, headings)
-    addHeadingBonuses(doc, headings)
+    addHeadingBonuses(headings)
     for el in headings:
-        addClass(el, 'settled')
-    if scope == "all" and doc.md.group in config.megaGroups['priv-sec']:
+        addClass(el, "settled")
+    if scope == "all" and doc.md.group in config.megaGroups["priv-sec"]:
         checkPrivacySecurityHeadings(findAll(".heading", doc))
 
 
-def resetHeadings(doc, headings):
+def resetHeadings(headings):
     for header in headings:
         # Reset to base, if this is a re-run
         if find(".content", header) is not None:
@@ -36,7 +34,7 @@ def resetHeadings(doc, headings):
             moveContents(header, content)
 
         # Insert current header contents into a <span class='content'>
-        content = E.span({"class":"content"})
+        content = E.span({"class": "content"})
         moveContents(content, header)
         appendChild(header, content)
 
@@ -44,16 +42,18 @@ def resetHeadings(doc, headings):
 def addHeadingIds(doc, headings):
     neededIds = set()
     for header in headings:
-        if header.get('id') is None:
+        if header.get("id") is None:
             if header.get("data-dfn-type") is None:
                 # dfn headings will get their IDs assigned by the dfn code
                 neededIds.add(header)
                 id = simplifyText(textContent(find(".content", header)))
-                header.set('id', safeID(doc, id))
+                header.set("id", safeID(doc, id))
     addOldIDs(headings)
     if len(neededIds) > 0:
-        warn("You should manually provide IDs for your headings:\n{0}",
-             "\n".join("  " + outerHTML(el) for el in neededIds))
+        warn(
+            "You should manually provide IDs for your headings:\n{0}",
+            "\n".join("  " + outerHTML(el) for el in neededIds),
+        )
 
 
 def checkPrivacySecurityHeadings(headings):
@@ -69,21 +69,27 @@ def checkPrivacySecurityHeadings(headings):
             # No need to look any further!
             return
     if not security and not privacy:
-        warn("This specification has neither a 'Security Considerations' nor a 'Privacy Considerations' section. Please consider adding both, see https://w3ctag.github.io/security-questionnaire/.")
+        warn(
+            "This specification has neither a 'Security Considerations' nor a 'Privacy Considerations' section. Please consider adding both, see https://w3ctag.github.io/security-questionnaire/."
+        )
     elif not security:
-        warn("This specification does not have a 'Security Considerations' section. Please consider adding one, see https://w3ctag.github.io/security-questionnaire/.")
+        warn(
+            "This specification does not have a 'Security Considerations' section. Please consider adding one, see https://w3ctag.github.io/security-questionnaire/."
+        )
     elif not privacy:
-        warn("This specification does not have a 'Privacy Considerations' section. Please consider adding one, see https://w3ctag.github.io/security-questionnaire/.")
+        warn(
+            "This specification does not have a 'Privacy Considerations' section. Please consider adding one, see https://w3ctag.github.io/security-questionnaire/."
+        )
 
 
-def addHeadingAlgorithms(doc, headings):
+def addHeadingAlgorithms(headings):
     for header in headings:
-        if header.get('data-algorithm') == "":
-            header.set('data-algorithm', textContent(header).strip())
+        if header.get("data-algorithm") == "":
+            header.set("data-algorithm", textContent(header).strip())
 
 
-def determineHeadingLevels(doc, headings):
-    headerLevel = [0,0,0,0,0]
+def determineHeadingLevels(headings):
+    headerLevel = [0, 0, 0, 0, 0]
 
     def incrementLevel(level):
         headerLevel[level - 2] += 1
@@ -91,32 +97,35 @@ def determineHeadingLevels(doc, headings):
             headerLevel[i] = 0
 
     def printLevel():
-        return '.'.join(str(x) for x in headerLevel if x > 0)
+        return ".".join(str(x) for x in headerLevel if x > 0)
 
-    skipLevel = float('inf')
+    skipLevel = float("inf")
     for header in headings:
         # Add the heading number.
         level = int(header.tag[-1])
 
         # Reset, if this is a re-run.
-        if(header.get('data-level')):
-            del header.attrib['data-level']
+        if header.get("data-level"):
+            del header.attrib["data-level"]
 
         # If we encounter a no-num or an appendix, don't number it or any in the same section.
-        if hasClass(header, "no-num") or textContent(header).lstrip()[0:9].lower() == "appendix ":
+        if (
+            hasClass(header, "no-num")
+            or textContent(header).lstrip()[0:9].lower() == "appendix "
+        ):
             skipLevel = min(level, skipLevel)
             continue
         if skipLevel < level:
             continue
-        else:
-            skipLevel = float('inf')
+
+        skipLevel = float("inf")
 
         incrementLevel(level)
-        header.set('data-level', printLevel())
+        header.set("data-level", printLevel())
 
 
-def addHeadingBonuses(doc, headings):
+def addHeadingBonuses(headings):
     for header in headings:
         if header.get("data-level") is not None:
-            secno = E.span({"class":"secno"}, header.get('data-level') + '. ')
+            secno = E.span({"class": "secno"}, header.get("data-level") + ". ")
             header.insert(0, secno)
