@@ -1,30 +1,33 @@
-# -*- coding: utf-8 -*-
-
 import sys
 from collections import Counter
+
 import lxml.html
+
 from . import constants
 
-
-
 messages = set()
 messageCounts = Counter()
 
 
 def p(msg, sep=None, end=None):
+    if constants.quiet == float("infinity"):
+        return
     if isinstance(msg, tuple):
         msg, ascii = msg
     else:
-        ascii = None
-    if constants.quiet == float("infinity"):
-        return
+        ascii = msg.encode("ascii", "replace").decode()
+    if constants.asciiOnly:
+        msg = ascii
     try:
         print(msg, sep=sep, end=end)
     except UnicodeEncodeError:
         if ascii is not None:
-            print(ascii.encode("ascii", "replace"))
+            print(ascii, sep=sep, end=end)
         else:
-            warning = formatMessage("warning", "Your console does not understand Unicode.\n  Messages may be slightly corrupted.")
+            warning = formatMessage(
+                "warning",
+                "Your console does not understand Unicode.\n  Messages may be slightly corrupted.",
+            )
             if warning not in messages:
                 print(warning)
                 messages.add(warning)
@@ -33,10 +36,10 @@ def p(msg, sep=None, end=None):
 
 def die(msg, *formatArgs, **namedArgs):
     lineNum = None
-    if 'el' in namedArgs and namedArgs['el'].get("line-number"):
-        lineNum = namedArgs['el'].get("line-number")
+    if "el" in namedArgs and namedArgs["el"].get("line-number"):
+        lineNum = namedArgs["el"].get("line-number")
     elif namedArgs.get("lineNum", None):
-        lineNum = namedArgs['lineNum']
+        lineNum = namedArgs["lineNum"]
     msg = formatMessage("fatal", msg.format(*formatArgs, **namedArgs), lineNum=lineNum)
     if msg not in messages:
         messageCounts["fatal"] += 1
@@ -50,39 +53,47 @@ def die(msg, *formatArgs, **namedArgs):
 def linkerror(msg, *formatArgs, **namedArgs):
     lineNum = None
     suffix = ""
-    if 'el' in namedArgs:
-        el = namedArgs['el']
+    if "el" in namedArgs:
+        el = namedArgs["el"]
         if el.get("line-number"):
             lineNum = el.get("line-number")
         else:
             if el.get("bs-autolink-syntax"):
-                suffix = "\n{0}".format(el.get("bs-autolink-syntax"))
+                suffix = "\n{}".format(el.get("bs-autolink-syntax"))
             else:
-                suffix = "\n{0}".format(lxml.html.tostring(namedArgs['el'], with_tail=False, encoding="unicode"))
+                suffix = "\n{}".format(
+                    lxml.html.tostring(
+                        namedArgs["el"], with_tail=False, encoding="unicode"
+                    )
+                )
     elif namedArgs.get("lineNum", None):
-        lineNum = namedArgs['lineNum']
-    msg = formatMessage("link", msg.format(*formatArgs, **namedArgs)+suffix, lineNum=lineNum)
+        lineNum = namedArgs["lineNum"]
+    msg = formatMessage(
+        "link", msg.format(*formatArgs, **namedArgs) + suffix, lineNum=lineNum
+    )
     if msg not in messages:
         messageCounts["linkerror"] += 1
         messages.add(msg)
         if constants.quiet < 2:
-                p(msg)
+            p(msg)
     if constants.errorLevelAt("link-error"):
         errorAndExit()
 
 
 def warn(msg, *formatArgs, **namedArgs):
     lineNum = None
-    if 'el' in namedArgs and namedArgs['el'].get("line-number"):
-        lineNum = namedArgs['el'].get("line-number")
+    if "el" in namedArgs and namedArgs["el"].get("line-number"):
+        lineNum = namedArgs["el"].get("line-number")
     elif namedArgs.get("lineNum", None):
-        lineNum = namedArgs['lineNum']
-    msg = formatMessage("warning", msg.format(*formatArgs, **namedArgs), lineNum=lineNum)
+        lineNum = namedArgs["lineNum"]
+    msg = formatMessage(
+        "warning", msg.format(*formatArgs, **namedArgs), lineNum=lineNum
+    )
     if msg not in messages:
         messageCounts["warning"] += 1
         messages.add(msg)
         if constants.quiet < 1:
-                p(msg)
+            p(msg)
     if constants.errorLevelAt("warning"):
         errorAndExit()
 
@@ -129,7 +140,7 @@ def printColor(text, color="white", *styles):
             "light blue": 94,
             "light magenta": 95,
             "light cyan": 96,
-            "white": 97
+            "white": 97,
         }
         stylesConverter = {
             "normal": 0,
@@ -141,38 +152,43 @@ def printColor(text, color="white", *styles):
             "blink": 5,
             "reverse": 7,
             "invert": 7,
-            "hidden": 8
+            "hidden": 8,
         }
 
         colorNum = colorsConverter[color.lower()]
         styleNum = ";".join(str(stylesConverter[style.lower()]) for style in styles)
-        return "\033[{0};{1}m{text}\033[0m".format(styleNum, colorNum, text=text)
-    else:
-        return text
+        return f"\033[{styleNum};{colorNum}m{text}\033[0m"
+    return text
 
 
 def formatMessage(type, text, lineNum=None):
     if constants.printMode == "markup":
         text = text.replace("<", "&lt;")
         if type == "fatal":
-            return "<fatal>{0}</fatal>".format(text)
-        elif type == "link":
-            return "<linkerror>{0}</linkerror>".format(text)
-        elif type == "warning":
-            return "<warning>{0}</warning>".format(text)
-        elif type == "message":
-            return "<message>{0}</message>".format(text)
-        elif type == "success":
-            return "<final-success>{0}</final-success>".format(text)
-        elif type == "failure":
-            return "<final-failure>{0}</final-failure>".format(text)
+            return f"<fatal>{text}</fatal>"
+        if type == "link":
+            return f"<linkerror>{text}</linkerror>"
+        if type == "warning":
+            return f"<warning>{text}</warning>"
+        if type == "message":
+            return f"<message>{text}</message>"
+        if type == "success":
+            return f"<final-success>{text}</final-success>"
+        if type == "failure":
+            return f"<final-failure>{text}</final-failure>"
     else:
         if type == "message":
             return text
         if type == "success":
-            return (printColor(" ✔ ", "green", "invert") + " " + text, printColor("YAY", "green", "invert") + " " + text)
+            return (
+                printColor(" ✔ ", "green", "invert") + " " + text,
+                printColor("YAY", "green", "invert") + " " + text,
+            )
         if type == "failure":
-            return (printColor(" ✘ ", "red", "invert") + " " + text, printColor("ERR", "red", "invert") + " " + text)
+            return (
+                printColor(" ✘ ", "red", "invert") + " " + text,
+                printColor("ERR", "red", "invert") + " " + text,
+            )
         if type == "fatal":
             headingText = "FATAL ERROR"
             color = "red"
@@ -183,9 +199,10 @@ def formatMessage(type, text, lineNum=None):
             headingText = "WARNING"
             color = "light cyan"
         if lineNum is not None:
-            headingText = "LINE {0}".format(lineNum)
+            headingText = f"LINE {lineNum}"
         return printColor(headingText + ":", color, "bold") + " " + text
 
+
 def errorAndExit():
     failure("Did not generate, due to fatal errors")
     sys.exit(2)
