@@ -1,11 +1,7 @@
-# -*- coding: utf-8 -*-
-
-
-
-class Repository(object):
-    '''
+class Repository:
+    """
     A class for representing spec repositories.
-    '''
+    """
 
     def __init__(self, url, name=None, type=None):
         self.ns = "com"
@@ -21,7 +17,7 @@ class Repository(object):
         else:
             self.type = "unknown"
 
-    def formatIssueUrl(self, *args, **kwargs):
+    def formatIssueUrl(self, *args, **kwargs):  # pylint: disable=unused-argument
         # Dunno how to format an arbitrary issue url,
         # so give up and just point to the repo.
         return self.url
@@ -29,7 +25,10 @@ class Repository(object):
 
 class GithubRepository(Repository):
     def __init__(self, ns, user, repo):
-        super(GithubRepository, self).__init__("https://github.{0}/{1}/{2}".format(ns, user, repo), "{0}/{1}".format(user, repo))
+        super().__init__(
+            f"https://github.{ns}/{user}/{repo}",
+            f"{user}/{repo}",
+        )
         self.ns = ns
         self.user = user
         self.repo = repo
@@ -37,12 +36,16 @@ class GithubRepository(Repository):
         if ns == "com":
             self.api = "https://api.github.com"
         else:
-            self.api = "https://github.{0}/api/v3".format(ns)
+            self.api = f"https://github.{ns}/api/v3"
 
     def formatIssueUrl(self, id=None):
         if id is None:
-            return "https://github.{0}/{1}/{2}/issues/".format(self.ns, self.user, self.repo)
-        return "https://github.{0}/{1}/{2}/issues/{3}".format(self.ns, self.user, self.repo, id)
+            return "https://github.{}/{}/{}/issues/".format(
+                self.ns, self.user, self.repo
+            )
+        return "https://github.{}/{}/{}/issues/{}".format(
+            self.ns, self.user, self.repo, id
+        )
 
     def __str__(self):
-        return "{0}/{1}".format(self.user, self.repo)
+        return f"{self.user}/{self.repo}"
