@@ -1,13 +1,17 @@
 import re
+
 from ..h import E, outerHTML
 from . import steps
 
+
 class DfnShorthand:
     def __init__(self):
         self.stage = "start"
         self.escapedText = None
         self.linkText = []
         self.bsAutolink = ""
+        self.linkFor = None
+        self.lt = None
 
     def respond(self, match, dom=None):
         if self.stage == "start":
@@ -33,14 +37,16 @@ class DfnShorthand:
             self.stage = "end"
             return steps.NextLiteral(endRe)
 
-    def respondLinkText(self, match, dom):
+    def respondLinkText(self, match, dom):  # pylint: disable=unused-argument
         self.linkText = dom
         self.bsAutolink += outerHTML(dom)
         return self.respondEnd()
 
     def respondEnd(self):
         if self.escapedText:
-            return steps.Success(skips=["["], nodes=[self.escapedText[1:], *self.linkText, "=]"])
+            return steps.Success(
+                skips=["["], nodes=[self.escapedText[1:], *self.linkText, "=]"]
+            )
 
         self.bsAutolink += "=]"
 
@@ -48,19 +54,22 @@ class DfnShorthand:
             self.linkText = self.lt
 
         attrs = {
-            "data-link-type":"dfn",
-            "for":self.linkFor,
-            "lt":self.lt,
-            "bs-autolink-syntax":self.bsAutolink}
-        return steps.Success(
-            E.a(attrs, linkText))
+            "data-link-type": "dfn",
+            "for": self.linkFor,
+            "lt": self.lt,
+            "bs-autolink-syntax": self.bsAutolink,
+        }
+        return steps.Success(E.a(attrs, self.linkText))
 
 
-DfnShorthand.startRe = re.compile(r"""
+DfnShorthand.startRe = re.compile(
+    r"""
     (\\)?
     \[=
     (?!\s)(?:([^=|]*)/)?
     ([^\"=]+?)
-    (?:\|)?""", re.X)
+    (?:\|)?""",
+    re.X,
+)
 
 endRe = re.compile("=]")
