@@ -1,23 +1,35 @@
-# -*- coding: utf-8 -*-
-
-
 import os
 
-from . import updateBackRefs
-from . import updateCrossRefs
-from . import updateBiblio
-from . import updateCanIUse
-from . import updateMdn
-from . import updateLinkDefaults
-from . import updateTestSuites
-from . import updateLanguages
-from . import updateWpt
-from . import manifest
 from .. import config
 from ..messages import *
+from . import (
+    manifest,
+    updateBackRefs,
+    updateBiblio,
+    updateCanIUse,
+    updateCrossRefs,
+    updateLanguages,
+    updateLinkDefaults,
+    updateMdn,
+    updateTestSuites,
+    updateWpt,
+)
 
 
-def update(anchors=False, backrefs=False, biblio=False, caniuse=False, linkDefaults=False, mdn=False, testSuites=False, languages=False, wpt=False, path=None, dryRun=False, force=False):
+def update(
+    anchors=False,
+    backrefs=False,
+    biblio=False,
+    caniuse=False,
+    linkDefaults=False,
+    mdn=False,
+    testSuites=False,
+    languages=False,
+    wpt=False,
+    path=None,
+    dryRun=False,
+    force=False,
+):
     if path is None:
         path = config.scriptPath("spec-data")
 
@@ -28,40 +40,41 @@ def update(anchors=False, backrefs=False, biblio=False, caniuse=False, linkDefau
             say("Falling back to a manual update...")
             force = True
     if force:
+        # fmt: off
         # If all are False, update everything
-        if  anchors == backrefs == biblio == caniuse == linkDefaults == mdn == testSuites == languages == wpt == False:
-            anchors  = backrefs  = biblio  = caniuse  = linkDefaults  = mdn  = testSuites  = languages  = wpt  = True
+        if anchors == backrefs == biblio == caniuse == linkDefaults == mdn == testSuites == languages == wpt == False:  # noqa: E712
+            anchors = backrefs =  biblio =  caniuse =  linkDefaults =  mdn =  testSuites =  languages =  wpt =  True  # noqa: E222
 
         touchedPaths = {
             "anchors": updateCrossRefs.update(path=path, dryRun=dryRun) if anchors else None,
             "backrefs": updateBackRefs.update(path=path, dryRun=dryRun) if backrefs else None,
             "biblio": updateBiblio.update(path=path, dryRun=dryRun) if biblio else None,
             "caniuse": updateCanIUse.update(path=path, dryRun=dryRun) if caniuse else None,
-            "mdnspeclinks": updateMdn.update(path=path, dryRun=dryRun) if mdn else None,
+            "mdn": updateMdn.update(path=path, dryRun=dryRun) if mdn else None,
             "linkDefaults": updateLinkDefaults.update(path=path, dryRun=dryRun) if linkDefaults else None,
             "testSuites": updateTestSuites.update(path=path, dryRun=dryRun) if testSuites else None,
             "languages": updateLanguages.update(path=path, dryRun=dryRun) if languages else None,
-            "wpt": updateWpt.update(path=path, dryRun=dryRun)if wpt else None
+            "wpt": updateWpt.update(path=path, dryRun=dryRun) if wpt else None,
         }
+        # fmt: on
 
         cleanupFiles(path, touchedPaths=touchedPaths, dryRun=dryRun)
         manifest.createManifest(path=path, dryRun=dryRun)
 
 
-
 def fixupDataFiles():
-    '''
+    """
     Checks the readonly/ version is more recent than your current mutable data files.
     This happens if I changed the datafile format and shipped updated files as a result;
     using the legacy files with the new code is quite bad!
-    '''
+    """
     try:
-        localVersion = int(open(localPath("version.txt"), 'r').read())
-    except IOError:
+        localVersion = int(open(localPath("version.txt")).read())
+    except OSError:
         localVersion = None
     try:
-        remoteVersion = int(open(remotePath("version.txt"), 'r').read())
-    except IOError as err:
+        remoteVersion = int(open(remotePath("version.txt")).read())
+    except OSError as err:
         warn("Couldn't check the datafile version. Bikeshed may be unstable.\n{0}", err)
         return
 
@@ -76,17 +89,19 @@ def fixupDataFiles():
         for filename in os.listdir(remotePath()):
             copyanything(remotePath(filename), localPath(filename))
     except Exception as err:
-        warn("Couldn't update datafiles from cache. Bikeshed may be unstable.\n{0}", err)
+        warn(
+            "Couldn't update datafiles from cache. Bikeshed may be unstable.\n{0}", err
+        )
         return
 
 
 def updateReadonlyDataFiles():
-    '''
+    """
     Like fixupDataFiles(), but in the opposite direction --
     copies all my current mutable data files into the readonly directory.
     This is a debugging tool to help me quickly update the built-in data files,
     and will not be called as part of normal operation.
-    '''
+    """
     try:
         for filename in os.listdir(localPath()):
             if filename.startswith("readonly"):
@@ -115,9 +130,9 @@ def cleanupFiles(root, touchedPaths, dryRun=False):
         deletableFiles.extend(["caniuse.json"])
         deletableFolders.extend(["caniuse"])
         paths.update(touchedPaths["caniuse"])
-    if touchedPaths["mdnspeclinks"] is not None:
-        deletableFolders.extend(["mdnspeclinks"])
-        paths.update(touchedPaths["mdnspeclinks"])
+    if touchedPaths["mdn"] is not None:
+        deletableFolders.extend(["mdn"])
+        paths.update(touchedPaths["mdn"])
 
     say("Cleaning up old data files...")
     oldPaths = []
@@ -130,14 +145,15 @@ def cleanupFiles(root, touchedPaths, dryRun=False):
             os.remove(absPath)
             oldPaths.append(relPath)
     if oldPaths:
-        say("Success! Deleted {0} old files.".format(len(oldPaths)))
+        say("Success! Deleted {} old files.".format(len(oldPaths)))
     else:
         say("Success! Nothing to delete.")
 
 
 def copyanything(src, dst):
-    import shutil
     import errno
+    import shutil
+
     try:
         shutil.rmtree(dst, ignore_errors=True)
         shutil.copytree(src, dst)
@@ -147,14 +163,17 @@ def copyanything(src, dst):
         else:
             raise
 
+
 def localPath(*segs):
     return config.scriptPath("spec-data", *segs)
 
+
 def remotePath(*segs):
     return config.scriptPath("spec-data", "readonly", *segs)
 
+
 def getDatafilePaths(basePath):
-    for root, dirs, files in os.walk(basePath):
+    for root, _, files in os.walk(basePath):
         for filename in files:
             filePath = os.path.join(root, filename)
             yield filePath, os.path.relpath(filePath, basePath)
